@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 
 
+import re
 import weakref
-import warnings
 
-from libraries.recipes import algorithms
+from util import algorithms
 import operation
 
 
@@ -15,6 +15,15 @@ __BASE_MAPPINGS = {
 }
 
 
+_VARIABLE_VALIDATION_RE = re.compile("^[a-zA-Z0-9]+$")
+
+
+def validate_variable_name(variableName):
+	match = _VARIABLE_VALIDATION_RE.match(variableName)
+	if match is None:
+		raise RuntimeError("Invalid characters in '%s'" % variableName)
+
+
 def parse_number(userInput):
 	try:
 		base = __BASE_MAPPINGS.get(userInput[0:2], 10)
@@ -102,6 +111,7 @@ class RpnCalcHistory(object):
 
 	def __init__(self, history, entry, errorReporting, constants, operations):
 		self.history = history
+		self.history._parse_value = self._parse_value
 		self.__entry = weakref.ref(entry)
 
 		self.__errorReporter = errorReporting
@@ -177,6 +187,7 @@ class RpnCalcHistory(object):
 		except KeyError:
 			pass
 
+		validate_variable_name(userInput)
 		return operation.Variable(userInput)
 
 	def _apply_operation(self, Node):
